@@ -11,8 +11,9 @@
 -- 1) Map for domains -> modules
 --
 -- Here you tell freepops what plugin should be used for you mailaddress domain
--- Some plugins acceprs som args. see popforward as an example of arg 
--- passing plugin.
+-- Some plugins accept some args. see popforward as an example of arg 
+-- passing plugin. If the plugin has regex set to true then the mailaddress
+-- will be considered a regexp.
 -- 
 
 -- this is the tutorial plugin...
@@ -44,6 +45,7 @@ freepops.MODULES_MAP["lycos.it"]	= {name="davmail.lua"}
 freepops.MODULES_MAP["lycos.at"]	= {name="davmail.lua"}
 freepops.MODULES_MAP["lycos.nl"]	= {name="davmail.lua"}
 freepops.MODULES_MAP["spray.se"]	= {name="davmail.lua"}
+freepops.MODULES_MAP["jubii.dk"]	= {name="davmail.lua"}
 
 -- gmail
 freepops.MODULES_MAP["gmail.com"]	= {name="gmail.lua"}
@@ -58,18 +60,21 @@ freepops.MODULES_MAP["yahoo.com.tw"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.uk"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.com.cn"] 	= {name="yahoo.lua"}
 freepops.MODULES_MAP["yahoo.es"] 	= {name="yahoo.lua"}
+freepops.MODULES_MAP["yahoo.dk"]        = {name="yahoo.lua"} 
 
 -- hotmail
-freepops.MODULES_MAP["hotmail.com"]	= {name="hotmail.lua"}
-freepops.MODULES_MAP["hotmail.de"]	= {name="hotmail.lua"}
-freepops.MODULES_MAP["hotmail.it"]	= {name="hotmail.lua"}
-freepops.MODULES_MAP["hotmail.co.uk"]	= {name="hotmail.lua"}
-freepops.MODULES_MAP["hotmail.co.jp"]	= {name="hotmail.lua"}
-freepops.MODULES_MAP["msn.com"]		= {name="hotmail.lua"}
-freepops.MODULES_MAP["webtv.com"]	= {name="hotmail.lua"}
-freepops.MODULES_MAP["charter.com"]	= {name="hotmail.lua"}
-freepops.MODULES_MAP["compaq.net"]	= {name="hotmail.lua"}
-freepops.MODULES_MAP["passport.com"]	= {name="hotmail.lua"}
+freepops.MODULES_MAP["hotmail.com"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["hotmail.de"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["hotmail.it"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["hotmail.co.uk"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["hotmail.co.jp"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["hotmail.fr"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["msn.com"]			= {name="hotmail.lua"}
+freepops.MODULES_MAP["webtv.com"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["charter.com"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["compaq.net"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["passport.com"]		= {name="hotmail.lua"}
+freepops.MODULES_MAP["messengeruser.com"]	= {name="hotmail.lua"}
 
 -- aol
 freepops.MODULES_MAP["aol.com"]		= {name="aol.lua"}
@@ -84,7 +89,10 @@ freepops.MODULES_MAP["jp.aol.com"]	= {name="aol.lua"}
 freepops.MODULES_MAP["aol.com.uk"]	= {name="aol.lua"}
 freepops.MODULES_MAP["aol.ca"]		= {name="aol.lua"}
 freepops.MODULES_MAP["aola.com"]	= {name="aol.lua"}
-freepops.MODULES_MAP["netscape.net"]    = {name="aol.lua"}
+freepops.MODULES_MAP["aim.com"]		= {name="aol.lua"}
+
+-- netscape
+freepops.MODULES_MAP["netscape.net"]    = {name="netscape.lua"}
 
 -- squirrelmail
 freepops.MODULES_MAP["mydom.com"]	= {name="squirrelmail.lua"}
@@ -117,13 +125,13 @@ freepops.MODULES_MAP["earthling.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["myself.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["post.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["techie.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["usa.com"]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["usa.com"]			= {name="mailcom.lua"}
 freepops.MODULES_MAP["writeme.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["2die4.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["artlover.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["bikerider.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["catlover.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["cliffhanger.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["cliffhanger.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["cutey.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["doglover.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["gardener.com"]		= {name="mailcom.lua"}
@@ -145,10 +153,9 @@ freepops.MODULES_MAP["africamail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["arcticmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["asia.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["australiamail.com"]	= {name="mailcom.lua"}
-freepops.MODULES_MAP["europe.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["japan.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["samerica.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["usa.com"]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["usa.com"]			= {name="mailcom.lua"}
 freepops.MODULES_MAP["berlin.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["dublin.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["london.com"]		= {name="mailcom.lua"}
@@ -158,7 +165,7 @@ freepops.MODULES_MAP["munich.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["nycmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["paris.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["rome.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["sanfranmail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["sanfranmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["singapore.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["tokyo.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["accountant.com"]		= {name="mailcom.lua"}
@@ -172,7 +179,7 @@ freepops.MODULES_MAP["columnist.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["comic.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["consultant.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["counsellor.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["deliveryman.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["deliveryman.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["diplomats.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["doctor.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["dr.com"]			= {name="mailcom.lua"}
@@ -181,7 +188,7 @@ freepops.MODULES_MAP["execs.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["financier.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["geologist.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["graphic-designer.com"]	= {name="mailcom.lua"}
-freepops.MODULES_MAP["hairdresser.net"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["hairdresser.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["insurer.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["journalist.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["lawyer.com"]		= {name="mailcom.lua"}
@@ -195,13 +202,13 @@ freepops.MODULES_MAP["presidency.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["priest.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["programmer.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["publicist.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["realtyagent.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["realtyagent.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["registerednurses.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["repairman.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["representative.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["rescueteam.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["scientist.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["sociologist.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["sociologist.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["teacher.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["techie.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["technologist.com"]	= {name="mailcom.lua"}
@@ -233,7 +240,7 @@ freepops.MODULES_MAP["blackburn-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["bsdmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["bsdmail.org"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["c-palace.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["celtic-mail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["celtic-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["charlton-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["chelsea-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["china139.com"]		= {name="mailcom.lua"}
@@ -262,9 +269,9 @@ freepops.MODULES_MAP["fastermail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["femail.ac"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["fiorentina-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["football-mail.com"]	= {name="mailcom.lua"}
-freepops.MODULES_MAP["forest-mail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["forest-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["freeid.net"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["fulham-mail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["fulham-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["gaywiredmail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["genkimail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["gigileung.org"]		= {name="mailcom.lua"}
@@ -279,7 +286,7 @@ freepops.MODULES_MAP["hitechweekly.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["hkis.org"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["hkmag.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["hkomail.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["hockey-mail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["hockey-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["hollywood-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["ii-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["iname.ru"]		= {name="mailcom.lua"}
@@ -287,16 +294,16 @@ freepops.MODULES_MAP["inboexes.org"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["inboxes.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["inboxes.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["inboxes.org"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["insingapore.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["insingapore.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["intermilan-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["ipswich-mail.com"]	= {name="mailcom.lua"}
-freepops.MODULES_MAP["isleuthmail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["isleuthmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["jane.com.tw"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["japan1.org"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["japanet.ac"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["japanmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["jayde.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["jcom.ac"]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["jcom.ac"]			= {name="mailcom.lua"}
 freepops.MODULES_MAP["jedimail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["joinme.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["joyo.com"]		= {name="mailcom.lua"}
@@ -333,11 +340,11 @@ freepops.MODULES_MAP["markguide.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["maxplanet.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["megacity.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["middlesbrough-mail.com"]	= {name="mailcom.lua"}
-freepops.MODULES_MAP["miriamyeung.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["miriamyeung.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["miriamyeung.com.hk"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["myoffice.ac"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["nctta.org"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["netmarketingcentral.com"]= {name="mailcom.lua"}
+freepops.MODULES_MAP["netmarketingcentral.com"] = {name="mailcom.lua"}
 freepops.MODULES_MAP["nettalk.ac"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["newcastle-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["nihonjin1.com"]		= {name="mailcom.lua"}
@@ -351,7 +358,7 @@ freepops.MODULES_MAP["outblaze.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["outgun.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["pakistans.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["pokefan.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["portugalnet.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["portugalnet.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["powerasia.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["qpr-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["rangers-mail.com"]	= {name="mailcom.lua"}
@@ -367,7 +374,7 @@ freepops.MODULES_MAP["slonline.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["smapxsmap.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["southampton-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["speedmail.ac"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["sports-mail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["sports-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["starmate.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["sunderland-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["sunmail.ac"]		= {name="mailcom.lua"}
@@ -378,7 +385,7 @@ freepops.MODULES_MAP["surfy.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["taiwan.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["talknet.ac"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["teddy.cc"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["tennis-mail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["tennis-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["tottenham-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["utsukushii.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["uymail.com"]		= {name="mailcom.lua"}
@@ -390,18 +397,29 @@ freepops.MODULES_MAP["wenxuecity.net"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["westham-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["wimbledon-mail.com"]	= {name="mailcom.lua"}
 freepops.MODULES_MAP["windrivers.net"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["wolves-mail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["wolves-mail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["wongfaye.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["worldmail.ac"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["worldweb.ac"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["isleuthmail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["isleuthmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["x-lab.cc"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["xy.com.tw"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["yankeeman.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["yyhmail.com"]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["verizonmail.com"]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["verizonmail.com"]		= {name="mailcom.lua"}
 freepops.MODULES_MAP["lycos.com" ]		= {name="mailcom.lua"}
-freepops.MODULES_MAP["unforgettable.com" ]		= {name="mailcom.lua"}
+freepops.MODULES_MAP["unforgettable.com" ]	= {name="mailcom.lua"}
+freepops.MODULES_MAP["mail.org" ]		= {name="mailcom.lua"}
+
+-- mail2world
+freepops.MODULES_MAP["mail2.*%.com" ]		= {name="mail2world.lua", 
+						   regex=true}
+
+-- juno plugin
+freepops.MODULES_MAP["netzero.net"]	= {name="juno.lua"}	
+freepops.MODULES_MAP["netzero.com"]	= {name="juno.lua"}	
+freepops.MODULES_MAP["juno.com"]   	= {name="juno.lua"}     
+
 
 -- popforward plugin
 
@@ -436,12 +454,12 @@ freepops.MODULES_MAP["flatnuke"] 	= {
 -- flatnuke binded domains
 freepops.MODULES_MAP["freepops.it"] 	= {
 	name="flatnuke.lua",
-	args={host="http://freepops.sourceforge.net/it"}
+	args={host="http://www.freepops.org/it"}
 }
 
 freepops.MODULES_MAP["freepops.en"] 	= {
 	name="flatnuke.lua",
-	args={host="http://freepops.sourceforge.net/en"}
+	args={host="http://www.freepops.org/en"}
 }
 
 -- rss backended news plugin
@@ -452,12 +470,12 @@ freepops.MODULES_MAP["aggregator"] 		= {
 -- rss binded domains
 freepops.MODULES_MAP["freepops.rss.en"] 	= {
 	name="aggregator.lua",
-	args={host="http://freepops.sf.net/en/misc/backend.rss"}
+	args={host="http://www.freepops.org/en/misc/backend.rss"}
 }
 
 freepops.MODULES_MAP["freepops.rss.it"] 	= {
 	name="aggregator.lua",
-	args={host="http://freepops.sf.net/it/misc/backend.rss"}
+	args={host="http://www.freepops.org/it/misc/backend.rss"}
 }
 
 freepops.MODULES_MAP["flatnuke.sf.net"] 	= {
