@@ -19,7 +19,7 @@
 	- CURLINFO ???
 	  
  ******************************************************************************
-   $Id: curl_lua.c,v 1.23 2005/03/28 10:25:52 gareuselesinge Exp $
+   $Id: curl_lua.c,v 1.24 2005/06/11 14:53:30 ncocchiaro Exp $
  ******************************************************************************/ 
 #include <lua.h>
 #include <lauxlib.h>
@@ -56,7 +56,7 @@
 	#define CURLOPT_HEADERDATA CURLOPT_WRITEHEADER
 #endif
 
-/* strings putted in the bag, vectorialized for faster/shorter access */
+/* strings put in the bag, vectorialized for faster/shorter access */
 	
         #define STR_CAINFO 		0
         #define STR_COOKIE 		1
