@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: popserver.c,v 1.10 2005/03/07 18:07:37 ncocchiaro Exp $
+ * $Id: popserver.c,v 1.11 2005/06/03 11:45:11 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -161,8 +161,14 @@ if(matches(SOCK_RECEIVED RFC_1939_PASS,c))
 	DBG("[%d] %s%s%s\n",pid,SOCK_RECEIVED,RFC_1939_PASS," *********");
 	}
 else	{
+	char * fmt = "[%d] %s\n";
 	if (matches(SOCK_INFO "A previous error occurred",c))
-		SAY("[%d] %s\n",pid,c);
+		SAY(fmt,pid,c);
+	if (matches(SOCK_ERROR "Error calling \"recvstring_with_timeout",c))
+		{
+		ERROR_SAY(fmt,pid,"Probably the client disconnected.");
+		ERROR_SAY(fmt,pid,"Try increasing the client timeout.\n");
+		}
 	DBG("[%d] %s\n",pid,c);	
 	}
 }
