@@ -1,5 +1,5 @@
 /******************************************************************************
- * $Id: altsocklib.c,v 1.8 2005/03/28 10:25:52 gareuselesinge Exp $
+ * $Id: altsocklib.c,v 1.9 2005/06/11 00:43:59 gareuselesinge Exp $
  * This file is part of liberopops (http://liberopops.sf.net)                 *
  * This file is distributed under the terms of GNU GPL license.               *
  ******************************************************************************/
@@ -318,7 +318,7 @@ return sd;
 int sockinfo(int sd, char *info)
 {
     struct sockaddr_in sin;
-#ifndef WIN32
+#if !defined(WIN32) && !defined(BEOS)
     socklen_t len = sizeof(sin);
 #else
     int len = sizeof(sin);
