@@ -7,18 +7,18 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.7"
+PLUGIN_VERSION = "0.0.8c"
 PLUGIN_NAME = "aol.com"
 PLUGIN_REQUIRE_VERSION = "0.0.21"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=aol.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=aol.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Russell Schwager"}
 PLUGIN_AUTHORS_CONTACTS = {"russells (at) despammed (.) com"}
 PLUGIN_DOMAINS = {
 "@aol.com","@aol.com.ar","@aol.fr","@aol.com.mx","@aol.com.au","@aol.de",
 "@aol.com.pr","@aol.com.br","@jp.aol.com","@aol.com.uk","@aol.ca","@aola.com", 
-"@netscape.net"} 
+"@netscape.net", "@aim.com"} 
 PLUGIN_PARAMETERS = 
 	{name="folder", description={
 		it=[[La cartella che vuoi ispezionare. Quella di default &egrave; Inbox. Gli altri valori possibili sono: Junk, Trash, Draft, Sent.]],
@@ -41,7 +41,7 @@ and your real password as the password.]]
 
 -- Domains supported:  aol.com, aol.com.ar, aol.fr, aol.com.mx, aol.com.au,
 --                     aol.de, aol.com.pr, aol.com.br, jp.aol.com, aol.co.uk,
---                     aol.ca, aola.com, netscape.net
+--                     aol.ca, aola.com, netscape.net, aim.com
 
 -- ************************************************************************** --
 --  Global Strings
@@ -51,6 +51,7 @@ local globals = {
   -- Server URL
   -- 
   strLoginUrl = "http://my.screenname.aol.com/_cqr/login/login.psp?seamless=novl&sitedomain=beta.webmail.aol.com&lang=en&locale=us&authLev=2&siteState=",
+  strLoginAIMUrl = "http://my.screenname.aol.com/_cqr/login/login.psp?mcState=initialized&seamless=novl&sitedomain=mail.aol.com&lang=en&locale=us&authLev=2&siteState=", --ver%3a1%252c0%26ld%3amail.aol.com",
 
   -- Login strings
   --
@@ -64,6 +65,7 @@ local globals = {
   -- Expressions to pull out of returned HTML from Hotmail corresponding to a problem
   --
   strRetLoginGoodLogin = 'gTargetHost = "([^"]+)"';
+  strRetLoginGoodLoginAim = 'gPreferredHost = "([^"]+)"';
   strRetLoginSessionNotExpired = "(mail session has expired)",
   
   -- Regular expression to extract the mail server
@@ -72,6 +74,7 @@ local globals = {
   -- Pattern to extract the URL to go to get the login form
   --
   strLoginPageParamsPattern='goToLoginUrl.-Redir."([^"]+)"',
+  strLoginPageParamsPatternAim = 'snsInFrameRedir."([^"]+)".;',
 
   -- Pattern to pull out the url's we need to go to set some cookies.
   --
@@ -81,6 +84,10 @@ local globals = {
   --
   strMsgListPrevPagePattern = '<A HREF="([^"]+)" CLASS="msglistbottomnav">Next</A>',
 
+  -- Pattern to extract the version of webmail
+  --
+  strVersionPattern = 'var VERSION[ ]?=[ ]?"([^"]+)";',
+
   -- Extract the server to post the login data to
   --
   strLoginPostUrlPattern1='[Mm][Ee][Tt][Hh][Oo][Dd]="[^"]*" [Aa][Cc][Tt][Ii][Oo][Nn]="([^"]*)"',
@@ -93,7 +100,7 @@ local globals = {
 
   -- Used by Stat to pull out the message ID and the size
   --
-  strMsgLinePattern = 'new parent%.MessageInfo%("([^"]+)",[^,]+,"[^,]+",[^,]+,([^,]+),',
+  strMsgLinePattern = 'new parent%.MessageInfo%("([^"]+)",[^,]+,"[^"]+",[^,]+,([^,]+),',
 
   -- Defined Mailbox names - These define the names to use in the URL for the mailboxes
   --
@@ -103,6 +110,11 @@ local globals = {
   strTrashAOL = "Recently%20Deleted",
   strSentAOL = "Sent%20Mail",
   StrSavedAOL = "Saved%20Mail",
+
+  strInboxAim = "Inbox",
+  strTrashAim = "Trash",
+  strSentAim = "Sent",
+  strDraftsAim = "Drafts",
   
   strTrashNetscape = "VHJhc2g=",
   strSentNetscape = "U2VudA==",
@@ -123,9 +135,10 @@ local globals = {
 
   -- Command URLS
   --
-  strCmdMsgList = "http://%s//GetMessageList.aspx?user=%s&page=%d&folder=%s&previousFolder=&stateToken=&newMailToken=&version=_SRV_1_0_0_11984_",
-  strCmdDelete = "http://%s/rpc_messages.aspx?folder=%s&action=delete&user=%s&version=_SRV_1_0_0_11984_", --&uid=X",
+  strCmdMsgList = "http://%s/GetMessageList.aspx?user=%s&page=%d&folder=%s&previousFolder=&stateToken=&newMailToken=&version=%s",
+  strCmdDelete = "http://%s/rpc_messages.aspx?folder=%s&action=delete&user=%s&version=%s", --&uid=X",
   strCmdMsgView = "http://%s/rfc822.aspx?user=%s&folder=%s&uid=%s",
+  strCmdWelcome = "http://%s/MessageList.aspx",
 
   -- Site IDs
   --
@@ -148,6 +161,7 @@ internalState = {
   strMBox = nil,
   strSiteId = "",
   strUserId = nil,
+  strVersion = "",
 }
 
 -- ************************************************************************** --
@@ -196,7 +210,10 @@ function loginAOL()
   local username = internalState.strUser
   local password = curl.escape(internalState.strPassword)
   local domain = internalState.strDomain
-  local url = string.format(globals.strLoginUrl, internalState.strSiteId)
+  local url = globals.strLoginUrl  --string.format(globals.strLoginUrl, internalState.strSiteId)
+  if (domain == "aim.com") then
+    url = globals.strLoginAIMUrl
+  end
   local xml = globals.strFolderQry
   local browser = internalState.browser
 	
@@ -231,7 +248,11 @@ function loginAOL()
   -- The login page sends us to a page that tests cookies and javascript.  We
   -- don't run javascript and thus must do the work here of pulling out the URL that
   -- the javascript would redirect too.
-  _, _, url = string.find(body, globals.strLoginPageParamsPattern)
+  if domain == "aim.com" then
+    _, _, url = string.find(body, globals.strLoginPageParamsPatternAim)
+  else
+    _, _, url = string.find(body, globals.strLoginPageParamsPattern)
+  end
   if (url == nil) then
     log.error_print("Unable to figure out the redirect on the login page.")
     return POPSERVER_ERR_UNKNOWN
@@ -289,7 +310,11 @@ function loginAOL()
 
   -- We should be logged in now! Let's check and make sure.
   --
-  local _, _, str = string.find(body, globals.strRetLoginGoodLogin)
+  local str = nil
+  _, _, str = string.find(body, globals.strRetLoginGoodLoginAim)
+  if str == nil then
+    _, _, str = string.find(body, globals.strRetLoginGoodLogin)
+  end
   if str == nil then
     log.error_print(globals.strLoginFailed)
     return POPSERVER_ERR_AUTH
@@ -301,7 +326,7 @@ function loginAOL()
 
   -- DEBUG Message
   --
-  log.dbg("AOL/Netscape Server: " .. internalState.strMailServer .. "\n")
+  log.dbg("AOL/AIM Server: " .. internalState.strMailServer .. "\n")
 
   -- Get UserID from cookie
   --
@@ -315,6 +340,17 @@ function loginAOL()
     end
   end
 
+  -- Get the webmail version
+  --
+  url = string.format(globals.strCmdWelcome, internalState.strMailServer)
+  body, err = browser:get_uri(url)
+  _, _, str = string.find(body, globals.strVersionPattern)
+  if (str == nil) then 
+    internalState.strVersion = "_SRV_1_0_0_12281_"
+  else
+    internalState.strVersion = str
+  end
+  log.dbg("AOL webmail version: " .. internalState.strVersion)
   
   -- Note that we have logged in successfully
   --
@@ -456,7 +492,11 @@ function user(pstate, username)
   --
   local mbox = (freepops.MODULE_ARGS or {}).folder
   if mbox == nil then
-    internalState.strMBox = globals.strInbox
+    if domain == "aim.com" then
+      internalState.strMBox = globals.strInboxAim
+    else
+      internalState.strMBox = globals.strInbox
+    end
     return POPSERVER_ERR_OK
   end
 
@@ -468,17 +508,21 @@ function user(pstate, username)
 
   _, _, start = string.find(mbox, globals.strSentPat)
   if start ~= nil then
-    if internalState.strSiteId == globals.strAOLID then
-      internalState.strMBox = globals.strSentAOL
+    if domain == "aim.com" then
+      internalState.strMBox = globals.strSentAim
     else
-      internalState.strMBox = globals.strSentNetscape
+      internalState.strMBox = globals.strSentAOL
     end
     return POPSERVER_ERR_OK
   end
 
   _, _, start = string.find(mbox, globals.strDeletedPat)
   if start ~= nil then
-    internalState.strMBox = globals.strTrashAOL
+    if domain == "aim.com" then
+      internalState.strMBox = globals.strTrashAim
+    else
+      internalState.strMBox = globals.strTrashAOL
+    end
     return POPSERVER_ERR_OK
   end
 
@@ -490,7 +534,7 @@ function user(pstate, username)
 
   _, _, start = string.find(mbox, globals.strDraftPat)
   if start ~= nil then
-    internalState.strMBox = globals.strDraftNetscape
+    internalState.strMBox = globals.strDraftAim
     return POPSERVER_ERR_OK
   end
 
@@ -589,7 +633,7 @@ function quit_update(pstate)
   local dcnt = 0
 
   local cmdUrl = string.format(globals.strCmdDelete, internalState.strMailServer, 
-    internalState.strMBox, internalState.strUserId)
+    internalState.strMBox, internalState.strUserId, internalState.strVersion)
   local baseUrl = cmdUrl
 
   -- Cycle through the messages and see if we need to delete any of them
@@ -657,7 +701,7 @@ function stat(pstate)
   local browser = internalState.browser
   local nMsgs = 0
   local cmdUrl = string.format(globals.strCmdMsgList, internalState.strMailServer, internalState.strUserId,
-    1, internalState.strMBox);
+    1, internalState.strMBox, internalState.strVersion);
   local baseUrl = cmdUrl
 
   -- Debug Message
@@ -741,7 +785,7 @@ function stat(pstate)
       --
       browser = internalState.browser
       cmdUrl = string.format(globals.strCmdMsgList, internalState.strMailServer,
-        internalState.strMBox)
+        internalState.strMBox, internalState.strVersion)
 
       -- Retry to load the page
       --
