@@ -1,10 +1,24 @@
---<==========================================================================>--
---<=                        FREEPOPS STARTUP FILE                           =>--
---<==========================================================================>--
+---
+-- FreePOPs bootstrap file. This is the entrypoint for the C core.
+-- This also includes some basic functions that can be used by plugins/scripts.
+-- 
 
+---
+-- The global freepops module.
 freepops = {}
+
+---
+-- A map between domains and plugins, see 
+-- <TT>config(dot)lua</TT> for a bunch of examples.
 freepops.MODULES_MAP = {}
-freepops.SO = {}
+
+---
+-- List of loaded so/dll/lua libs.
+freepops.LOADED = {}
+
+---
+-- This is a global variable that the plugins may read, see the libero plugin
+-- for an example.
 freepops.MODULE_ARGS = nil
 
 --<==========================================================================>--
@@ -23,23 +37,79 @@ fp_m = {
 
 setmetatable(freepops,fp_m)
 
+--<==========================================================================>--
+-- Local functions
+
+local __dofile = dofile
+local __loadlib = loadlib
+local __loadfile = loadfile
+
+-- Config file loading.
+local function load_config()
+
+	local paths = { 
+		"/etc/freepops/",
+		"./",
+		os.getenv("FREEPOPSLUA_PATH") or "./" ,
+	}
+
+	local try_load = function (_,p)
+		local h = __loadfile(p .. "config.lua")
+		if h ~= nil then 
+			h() 
+			return true
+		else
+			return nil
+		end
+	end
+
+	local rc = table.foreachi(paths,try_load)
+
+	if rc == nil then
+		error("Unable to load config.lua. Path is "..
+			table.concat(paths,":"))
+	end
+
+end
+
+-- Required methods for a plugin.
+local pop3_methods = {
+	"user","pass",
+	"list","list_all",
+	"uidl","uidl_all",
+	"stat",
+	"retr","top",
+	"rset","noop","dele",
+	"quit","quit_update",
+	"init",
+}
+
 --<==========================================================================>--
 -- these are global helpers for all freepops modules
 
--- function to extract domain part of a mailaddress
-freepops.get_domain = function (mailaddress)
+---
+-- function to extract domain part of a mailaddress.
+-- @param mailaddress string for example pippo@libero.it?param=value.
+-- @return string The text between @ and (?|$). In our example 'libero.it'.
+function freepops.get_domain(mailaddress)
 	local _,_,ad = string.find(mailaddress,"[^@]+@([^?]+).*")
 	return ad
 end
 
--- function to extract the username part of a mailaddress
-freepops.get_name = function (mailaddress)
+---
+-- function to extract the username part of a mailaddress.
+-- @param mailaddress string for example pippo@libero.it?param=value.
+-- @return string The text between ^ and @. in our example pippo.
+function freepops.get_name(mailaddress)
 	local _,_,ad = string.find(mailaddress,"([^@]+)@[^?]+.*")
 	return ad
 end
 
--- function to extract the parameters part of a mailaddress
-freepops.get_args = function (mailaddress)
+---
+-- function to extract the parameters part of a mailaddress.
+-- @param mailaddress string for example pippo@libero.it?par1=val1&par2=val2.
+-- @return table in our example {par1=val1 ; par2=val2}.
+function freepops.get_args(mailaddress)
 	local _,_,ad = string.find(mailaddress,"[^@]+@[^?%s]+([?%s].*)")
 	local args = {}
 	local function extract_arg(s)
@@ -88,9 +158,13 @@ freepops.get_args = function (mailaddress)
 	return args
 end
 
--- extracts a list of supported domain from a plugin file
--- (the plugin is executed in a protected environment, 
--- no pollution but computations are done)
+---
+-- Extracts a list of supported domain from a plugin file.
+-- The plugin is executed in a protected environment, 
+-- no pollution but computations are done.
+-- @param f string The path of the lua plugin file.
+-- @return table A couple of tables, the list of domains and
+-- the list of regexes.
 function freepops.safe_extract_domains(f)
 	local env = {}
 	local meta_env = { __index = _G }
@@ -106,32 +180,51 @@ function freepops.safe_extract_domains(f)
 	g()
 	
 	-- checks 
-	if type(env.PLUGIN_DOMAINS) ~= "table" then
-		return nil
+	local check_types = function(t)
+		return table.foreachi(t,function(k,v)
+			if type(v) ~= "string" then
+				print("'"..tostring(v).."' is not a string")
+				return true
+			end
+			if string.byte(v) ~= string.byte("@") then
+				print("'"..v.."' does not start with @")
+				return true
+			end
+		end)
 	end
-	local rc = table.foreachi(env.PLUGIN_DOMAINS,function(k,v)
-		if type(v) ~= "string" then
-			print("'"..tostring(v).."' is not a string")
-			return true
-		end
-		if string.byte(v) ~= string.byte("@") then
-			print("'"..v.."' does not start with @")
-			return true
-		end
-	end)
-	if rc then return nil end
 	
+	if env.PLUGIN_DOMAINS ~= nil then
+		if type(env.PLUGIN_DOMAINS) ~= "table" then return nil end
+		if check_types(env.PLUGIN_DOMAINS) then return nil end
+	end
+	
+	if env.PLUGIN_REGEXES ~= nil then
+		if type(env.PLUGIN_REGEXES) ~= "table" then return nil end
+		if check_types(env.PLUGIN_REGEXES) then return nil end
+	end
+
 	-- extract
-	local rc = {}
-	table.foreachi(env.PLUGIN_DOMAINS,function(_,v)
-		local x = string.sub(v,2,-1)
-		table.insert(rc,x)
-	end)
+	local rc, rd = {}, {}
+	if env.PLUGIN_DOMAINS ~= nil then
+		table.foreachi(env.PLUGIN_DOMAINS,function(_,v)
+			local x = string.sub(v,2,-1)
+			table.insert(rc,x)
+		end)
+	end
+	if env.PLUGIN_REGEXES ~= nil then
+		table.foreachi(env.PLUGIN_REGEXES,function(_,v)
+			local x = string.sub(v,2,-1)
+			table.insert(rd,x)
+		end)
+	end
 	
-	return rc
+	return rc,rd
 end
 
---searches if an unofficial plugin handles this domain
+---
+-- Searches if an unofficial plugin handles this domain.
+-- @param domain string The domain you want to handle.
+-- @return string A couple, name and path.
 function freepops.search_domain_in_unofficial(domain)
 	local function is_in_table(x,t)
 		if t == nil then return false end
@@ -139,7 +232,15 @@ function freepops.search_domain_in_unofficial(domain)
 			if v == x then return true end
 		end) or false
 	end
-	return table.foreach(freepops.MODULES_PREFIX_UNOFFICIAL,function(_,v)
+	local function match_regex(x,t)
+		if t == nil then return false end
+		return table.foreach(t,function(_,v)
+			local w,_ = string.find(x,"^" .. v .. "$")
+			if w ~= nil then return true end
+		end)
+	end	
+	local name, where = nil, nil
+	table.foreach(freepops.MODULES_PREFIX_UNOFFICIAL,function(_,v)
 		local it = nil
 		local p_dir = function() it = lfs.dir(v) end
 		local rc,err = pcall(p_dir)
@@ -149,21 +250,30 @@ function freepops.search_domain_in_unofficial(domain)
 		end
 		for f in it do
 			if string.upper(string.sub(f,-3,-1)) == "LUA" then
-				local h = 
+				local h,rex = 
 					freepops.safe_extract_domains(v.."/"..f)
 				if is_in_table(domain,h) then
-					log.dbg("Using unofficial '"..
-						v.."/"..f.."'")
-					return v.."/"..f
+					name, where =  v.."/"..f, "unofficial"
+					return true -- stop loop
+				elseif match_regex(domain,rex) then
+					name, where =  
+						v.."/"..f, "unofficial(regex)"
+					return true -- stop loop
 				end
 			end
 		end	
 	end)
+
+	return name, where
 end
 
-
--- to merge 2 tables (t1 wins over t)
-freepops.table_overwrite = function (t,t1)  
+---
+-- Merge 2 tables.
+-- t is destroyed, and t1 wins over t.
+-- @param t table The slave table.
+-- @param t1 table The master table.
+-- @return table the union (t1 wins over t).
+function freepops.table_overwrite(t,t1)  
 	t = t or {}
 	t1 = t1 or {}
 	table.foreach(t1, function(k,v)
@@ -172,99 +282,160 @@ freepops.table_overwrite = function (t,t1)
 	return t
 end
 
--- function that maps domains to modules
-freepops.choose_module = function (d)
-	if d == nil then return nil,nil end
-	if freepops.MODULES_MAP[d] == nil then 
-		local _,_,x = string.find(d,"^(%w+%.lua)$")
-		if x == nil then
-			local unoff = freepops.search_domain_in_unofficial(d)
-			if unoff then
-				return unoff,{}
-			else
-				return nil,nil
+---
+-- function that maps domains to modules.
+-- These are the rules that will be honored to choose the module:</BR>
+-- 0th: if domain d is nil then fail</BR>
+-- 1st: check if a verbatim mapping exists (freepops.MODULES_MAP[d] ~= nil)</BR>
+-- 2nd: check if a plugin tagged regex matches</BR>
+-- 3rd: check if the mailaddress is a plugin name</BR>
+-- 4th: check if an unofficial plugin matches verbatim</BR>
+-- 5th: check if an unofficial plugin tagged regex matches.
+-- @param d string The domain.
+-- @return found, where, name, args.
+function freepops.choose_module(d)
+	local found, where, name, args = false, "nowhere", nil, nil
+	
+	-- 0th: if domain d is nil then fail
+	if d == nil then 
+		found, where, name, args = true, "nowhere", nil, nil 
+	end
+
+	-- 1st: check if a verbatim mapping exists 
+	if not found and freepops.MODULES_MAP[d] ~= nil then
+		found, where, name, args = true, "official", 
+			freepops.MODULES_MAP[d].name,
+			freepops.MODULES_MAP[d].args
+	end
+	 
+	-- 2nd: check if a plugin tagged regex matches
+	if not found then
+		local plugins_with_regex = {}
+		table.foreach(freepops.MODULES_MAP, function (k,v)
+			if v.regex then
+				plugins_with_regex[k] = v
 			end
+		end)
+		table.foreach(plugins_with_regex,function(k,v)
+			local x,_ = string.find(d,"^" .. k .. "$")
+			if x ~= nil then
+				found, where, name, args = 
+					true, "official(regex)", v.name, v
+				return true -- stop iteration
+			end
+		end)
+	end
+	
+	-- 3rd: check if the mailaddress is a plugin name
+	if not found then 
+		local _,_,x = string.find(d,"^(%w+%.lua)$")
+		if x ~= nil then
+			found, where, name, args = 
+				true, "inline", x, {}
 		end
-		return x,{}
 	end	
-	return 	freepops.MODULES_MAP[d].name,freepops.MODULES_MAP[d].args
+	-- 4th: check if an unofficial plugin matches verbatim
+	-- 5th: check if an unofficial plugin tagged regex matches
+	if not found then
+		local unoff, wh = freepops.search_domain_in_unofficial(d)
+		if unoff ~= nil then
+			log.dbg("Using unofficial '"..unoff.."'")
+			found, where, name, args = true, wh, unoff, {}
+		end
+	end
+	
+	return name, args, where 
 end
 
--- dofile with freepops.MODULES_PREFIX path
-freepops.dofile = function (file)
-	local got = nil
-	local try_do = function (index,path)
+---
+-- Searches a file in $CWD + MODULES_PREFIX and returns the full path or nil.
+-- @param file string The ifle name.
+-- @return string The full path or nil.
+function freepops.find(file)
+	local try = function(_,path)
 		local f,_ = io.open(path..file,"r")
 		if f ~= nil then
 			io.close(f)
-			freepops.__dofile(path..file)
-			got = 1
-			return 0 -- stop looping
-		else
-			return nil -- continue looping
+			return path..file
 		end
 	end
-
-	-- first check for absolute path
-	try_do(0,"")
-	if not got then
-		table.foreach(freepops.MODULES_PREFIX,try_do)
+	if try(_,"") ~= nil then
+		return file
 	end
-	if not got then
+	return table.foreach(freepops.MODULES_PREFIX,try)
+end
+
+---
+-- As the standard LUA dofile but with MODULES_PREFIX path.
+-- @return number 0 if OK, nil if not.
+function freepops.dofile(file)
+	local got = freepops.find(file)
+	if got == nil then
 		log.error_print(string.format("Unable to find '%s'\n",file))
 		log.error_print(string.format("Path is '%s'\n",
 			table.concat(freepops.MODULES_PREFIX,":")))
+		return nil
+	else
+		__dofile(got)
+		return 0
 	end
-	return got
 end
-freepops.__dofile = dofile
-dofile = freepops.dofile
 
--- load a shared library with freepops.MODULES_PREFIX path
-freepops.loadlib = function (file,fname)
-	local got = nil
-	local try_do = function (index,path)
-		local f,_ = io.open(path..file,"r")
-		if f ~= nil then
-			io.close(f)
-			local g,err = freepops.__loadlib(path..file,fname)
-			if not g then
-				log.error_print(path..file..": "..err.."\n")
-				return nil
-			else
-				g()
-				got = 1
-				return 0 -- stop looping
-			end
-		else
-			return nil -- continue looping
-		end
-	end
-	local function foo() end
+---
+-- As the standard LUA loadlib but with MODULES_PREFIX path.
+-- Load a shared library (or even a .lua file).
+-- Checks if the file has been already loaded.
+-- Should be preferred to freepops.dofile().
+-- @param file string The object name.
+-- @param fname string The function to call (nil in case the object is a lua).
+-- @return function The result of a LUA loadfile or nil.
+function freepops.loadlib(file,fname)
 	-- check if already loaded
-	if freepops.SO[file] then
-		return foo
+	if freepops.LOADED[file] ~= nil then
+		return function() end 
 	end
-	-- load it
-	table.foreach(freepops.MODULES_PREFIX,try_do)
+	
+	local got = freepops.find(file)
+	
 	-- check result
-	if not got then
+	if got == nil then
 		log.error_print(string.format("Unable to load '%s'\n",file))
 		log.error_print(string.format("Path is '%s'\n",
 			table.concat(freepops.MODULES_PREFIX,":")))
 		return nil
 	else
-		freepops.SO[file] = 1	
-		return foo
+		local x,_ = string.find(file, "%.lua$")
+		local g, err = nil, nil
+		
+		if x ~= nil then
+			-- we are loading a .lua file
+			g, err = __loadfile(got)
+		else
+			g, err = __loadlib(got, fname)
+		end
+		if not g then
+			log.error_print(got..": "..err.."\n")
+			return nil
+		else
+			freepops.LOADED[file] = true
+			return g
+		end
 	end
 end
 
--- prevent using the real loadlib
-freepops.__loadlib = loadlib
+---
+-- uses freepops' dofile instead of the standard one.
+dofile = freepops.dofile
+---
+-- uses freepops' loadlib instead of the standard one.
 loadlib = freepops.loadlib
+---
+-- uses freepops' loadfile instead of the standard one.
+loadfile = freepops.loadlib
 
--- load needed module for handling domain
-freepops.load_module_for = function (mailaddress,loadonly)
+---
+-- Load needed module for handling domain.
+function freepops.load_module_for(mailaddress,loadonly)
 	-- helpers
 	local function err_format(dom,mail) 
 		return string.format(
@@ -281,7 +452,7 @@ freepops.load_module_for = function (mailaddress,loadonly)
 	* parte @qualcosa. FreePOPs ha bisogno di username con      *
 	* un dominio. Se eri un utente LiberoPOPs puoi leggere      *
 	*                                                           *
-	*   http://freepops.sourceforge.net/it/lp_to_fp.shtml       *
+	*   http://www.freepops.org/it/lp_to_fp.shtml       *
 	*                                                           *
 	* che spiega cosa devi esattamente fare. Per favore non     *
 	* mettere richieste di aiuto sul forum se non hai           *
@@ -297,11 +468,11 @@ freepops.load_module_for = function (mailaddress,loadonly)
 	* must use a username in the form foo@something to use      *
 	* FreePOPs. Please read the manual available at             *
 	*                                                           *
-        *   http://freepops.sourceforge.net/en/files/manual.pdf     *
+        *   http://www.freepops.org/en/files/manual.pdf     *
 	*                                                           *
 	* or the tutorial                                           *
 	*                                                           *
-	*   http://freepops.sourceforge.net/en/tutorial/index.shtml *
+	*   http://www.freepops.org/en/tutorial/index.shtml *
 	*                                                           *
 	*************************************************************
 ]]
@@ -326,7 +497,7 @@ freepops.load_module_for = function (mailaddress,loadonly)
 
 	-- the stuff
 	local domain = freepops.get_domain(mailaddress)
-	local module,args = freepops.choose_module(domain)
+	local module,args,where = freepops.choose_module(domain)
 	if module == nil then
 		if domain ~= nil then
 			log.error_print(err_format(domain,mailaddress))
@@ -341,7 +512,8 @@ freepops.load_module_for = function (mailaddress,loadonly)
 		--table.foreach(args,print)
 		--print("PARSED ARGS:")
 		--table.foreach(freepops.get_args(mailaddress),print)
-		
+		--print("plugin found: ",where)
+
 		local marg = freepops.table_overwrite(args,
 			freepops.get_args(mailaddress))
 		
@@ -355,12 +527,16 @@ freepops.load_module_for = function (mailaddress,loadonly)
 	
 end
 
--- checks if this FreePOPs version is enough for the plugin
-freepops.enough_new = function(plugin_version_string)
-	local fp_version_string = os.getenv("FREEPOPS_VERSION")
+---
+-- Compares 2 verions in FreePOPs format.
+-- This is the LUA regex to extract the components: "(%d+)%.(%d+)%.(%d+)".
+-- @param version1 string A version.
+-- @param version2 string A version.
+-- @return boolean true if version1 >= version2.
+function freepops.is_version_ge(version1, version2)
 	local match = "(%d+)%.(%d+)%.(%d+)"
-	local _,_,fp_x,fp_y,fp_z = string.find(fp_version_string,match)
-	local _,_,p_x,p_y,p_z = string.find(plugin_version_string,match)
+	local _,_,fp_x,fp_y,fp_z = string.find(version1, match)
+	local _,_,p_x,p_y,p_z = string.find(version2, match)
 	if fp_x == nil or fp_y == nil or fp_z == nil then
 		log.error_print("Wrong FreePOPs version string format")
 		return false
@@ -381,28 +557,28 @@ freepops.enough_new = function(plugin_version_string)
 	return false
 end
 
--- makes tab members globals
-freepops.export = function(tab)
+---
+-- Checks if this FreePOPs version is enough for the plugin.
+function freepops.enough_new(plugin_version_string)
+	local fp_version_string = os.getenv("FREEPOPS_VERSION")
+	return freepops.is_version_ge(fp_version_string, 
+						plugin_version_string)
+end
+
+---
+-- Makes tab members globals.
+function freepops.export(tab)
 	local _export = function(name,value) 
 		_G[name]=value 
 	end
 	table.foreach(tab,_export)
 end
 
--- required methods
-local pop3_methods = {
-	"user","pass",
-	"list","list_all",
-	"uidl","uidl_all",
-	"stat",
-	"retr","top",
-	"rset","noop","dele",
-	"quit","quit_update",
-	"init",
-}
 
--- checks if the plugin has declared all required methods
-freepops.check_global_symbols = function()
+---
+-- Checks if the plugin has declared all required methods.
+-- This should be called after the plugin is loaded.
+function freepops.check_global_symbols()
 	for _,v in ipairs(pop3_methods) do
 		if _G[v] == nil then
 			log.error_print("The plugin has not declared '"..v.."'")
@@ -412,8 +588,10 @@ freepops.check_global_symbols = function()
 	return true
 end
 
--- checks for wrong globals usage
-freepops.set_sanity_checks = function()
+---
+-- Sets a metatable for _G that checks for wrong globals usage.
+-- No more globals can be declared after this function is called.
+function freepops.set_sanity_checks()
 	-- no more globals can be declared after this (except _)
 	setmetatable(_G,{
 		__index = function(t,k)
@@ -450,8 +628,9 @@ freepops.set_sanity_checks = function()
 	})
 end
 
--- checks if this version of FP is SSL enabled
--- !! must be called after loading the browser module !!
+---
+-- Checks if this version of FP is SSL enabled.
+-- Must be called after loading the browser module.
 function freepops.need_ssl()
 	local c = browser.ssl_enabled()
 	if not c then
@@ -469,11 +648,12 @@ function freepops.need_ssl()
 	end
 end
 
-
--- checks if the address a is matched by the strings defined in table t
+---
+-- Checks if the address a is matched by the strings defined in table t.
 function freepops.match_address(a,t)
 	local why = ""
 	local rc = table.foreach(t,function(k,v)
+		-- what is this? boh...
 		local capt = "^(" .. v .. ")$"
 		local _,_,x = string.find(a,capt)
 		if x ~= nil then 
@@ -489,63 +669,56 @@ function freepops.match_address(a,t)
 	end
 end
 
---<==========================================================================>--
--- Local functions
-
--- config file loading
-local function load_config()
-
-	local paths = { 
-		"/etc/freepops/",
-		"./",
-		os.getenv("FREEPOPSLUA_PATH") or "./" ,
-	}
-
-	local try_load = function (_,p)
-		local h = loadfile(p .. "config.lua")
-		if h ~= nil then 
-			h() 
-			return true
-		else
-			return nil
-		end
-	end
-
-	local rc = table.foreachi(paths,try_load)
-
-	if rc == nil then
-		error("Unable to load config.lua. Path is "..
-			table.concat(paths,":"))
-	end
-
-end
 
 --<==========================================================================>--
 -- This is the function freepops calls
 
 -- -------------------------------------------------------------------------- --
---  This is the only function called from the C code. This loads the module
---  that handles mailaddress's domain and load standard LUA modules
+-- freepops.dofile may be called too by the C core to execute a script that is
+-- not found (and so it is searched in the standard paths)
 -- -------------------------------------------------------------------------- --
-freepops.init = function (mailaddress,loadonly)
+
+-- -------------------------------------------------------------------------- --
+-- This is only the LUA box bootstrap code. This is called to initialize the
+-- lua box when freepops is started with -e or -x
+-- -------------------------------------------------------------------------- --
+
+---
+-- Load the configuration file and the support module.
+-- Is intended to be used by the C core.
+function freepops.bootstrap()
 	load_config()
 	
 	-- standard lua modules that must be loaded
 	if freepops.dofile("support.lua") == nil then return 1 end
+
+	return 0 -- OK
+end
+
+-- -------------------------------------------------------------------------- --
+--  This is the only (except the latter) function called from the C code. 
+--  This loads the module that handles mailaddress's domain and load standard
+--  LUA modules
+-- -------------------------------------------------------------------------- --
+
+---
+-- Load the configuration file and the support module and the plugin that
+-- handles mailaddress.
+-- Is intended to be used by the C core.
+function freepops.init(mailaddress)
+	freepops.bootstrap()
 	
 	if freepops.load_module_for(mailaddress) == nil then return 1 end
 	
-	if loadonly == 0 then
-		-- check if the required version is older
-		if not freepops.enough_new(PLUGIN_REQUIRE_VERSION) then
-			log.error_print(
-				"This plugin requires a newer version "..
-				"of FreePOPs. Please update!")
-			return 1
-		end
-		-- some sanity checks
-		if freepops.check_global_symbols() == nil then return 1 end
+	-- check if the required version is older
+	if not freepops.enough_new(PLUGIN_REQUIRE_VERSION) then
+		log.error_print(
+			"This plugin requires a newer version "..
+			"of FreePOPs. Please update!")
+		return 1
 	end
+	-- some sanity checks
+	if freepops.check_global_symbols() == nil then return 1 end
 	
 	return 0 -- OK
 end
