@@ -7,23 +7,24 @@
 
 -- Globals
 --
-PLUGIN_VERSION = "0.0.9a"
+PLUGIN_VERSION = "0.1.0"
 PLUGIN_NAME = "hotmail.com"
-PLUGIN_REQUIRE_VERSION = "0.0.15"
+PLUGIN_REQUIRE_VERSION = "0.0.25"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=hotmail.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=hotmail.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 PLUGIN_AUTHORS_NAMES = {"Russell Schwager"}
 PLUGIN_AUTHORS_CONTACTS = {"russells (at) despammed (.) com"}
 PLUGIN_DOMAINS = {"@hotmail.com","@msn.com","@webtv.com","@charter.com",
 	"@compaq.net","@passport.com", "@hotmail.de", "@hotmail.it", "@hotmail.co.uk", 
-        "@hotmail.co.jp"}
+        "@hotmail.co.jp", "@hotmail.fr", "@messengeruser.com"}
 PLUGIN_PARAMETERS = {
 	{name="folder", description={
-		it=[[La cartella che vuoi ispezionare. Quella di default &egrave; Inbox. Gli altri valori possibili sono: Junk, Trash, Draft, Sent.]],
+		it=[[La cartella che vuoi ispezionare. Quella di default &egrave; Inbox, gli altri valori possibili sono: Junk, Trash, Draft, Sent.]],
 		en=[[The folder you want to interact with. Default is Inbox, other values are: Junk, Trash, Draft, Sent.]]}
 	},
 	{name = "emptytrash", description = {
+		it = [[ Viene usato per forzare il plugin a svuotare il cestino quando ha finito di scaricare i messaggi. Se il valore &egrave; 1 questo comportamento viene attivato.]],
 		en = [[
 Parameter is used to force the plugin to empty the trash when it is done
 pulling messages.  Set the value to 1.]]
@@ -33,9 +34,11 @@ pulling messages.  Set the value to 1.]]
 }
 PLUGIN_DESCRIPTIONS = {
 	it=[[
+Questo plugin vi permette di scaricare la posta da mailbox con dominio della famiglia di @hotmail.com. 
 Per usare questo plugin dovrete usare il vostro indirizzo email completo come 
 nome utente e la vostra vera password come password.]],
 	en=[[
+This plugin lets you download mail from @hotmail.com and similar mailboxes. 
 To use this plugin you have to use your full email address as the username
 and your real password as the password.  For support, please post a question to
 the forum instead of emailing the author(s).]]
@@ -60,7 +63,7 @@ local globals = {
   -- Login strings
   -- TODO: Define the HTTPS version
   --
-  strLoginPostData = "login=%s&domain=%s&passwd=%s&sec=&mspp_shared=&padding=%s",
+  strLoginPostData = "login=%s&domain=%s&passwd=%s&sec=&mspp_shared=&PwdPad=%s&PPSX=Pas&LoginOptions=3",
   strLoginPaddingFull = "xxxxxxxxxxxxxxxx",
   strLoginFailed = "Login Failed - Invalid User name and/or password",
 
@@ -75,10 +78,12 @@ local globals = {
   
   -- Extract the server to post the login data to
   --
-  strLoginPostUrlPattern1='name=[%w]+ action="([^"]*)"',
-  strLoginPostUrlPattern2='name="([^"]*)" value="([^"]*)"',
-  strLoginPostUrlPattern3='<form TARGET="_top" name="%s" action="([^"]*)"',
-  strLoginDoneReloadToHMHome='URL=(.*[^"])"',
+  strLoginPostUrlPattern1='action="([^"]*)"',
+  strLoginPostUrlPattern2='type=["]?hidden["]? name="([^"]*)".* value="([^"]*)"',
+  strLoginPostUrlPattern3='g_DO."%s".="([^"]+)"',
+  strLoginPostUrlPattern4='var g_QS="([^"]+)";',
+  strLoginPostUrlPattern5='name="PPFT" id="[^"]+" value="([^"]+)"',
+  strLoginDoneReloadToHMHome='URL=([^"]+)"',
 
   -- Get the crumb value that is needed for every command
   --
@@ -240,6 +245,7 @@ function loginHotmail()
   local postdata = nil
   local name, value  
   for name, value in string.gfind(body, globals.strLoginPostUrlPattern2) do
+    value = curl.escape(value)
     if postdata ~= nil then
       postdata = postdata .. "&" .. name .. "=" .. value  
     else
@@ -252,12 +258,21 @@ function loginHotmail()
   -- Pull out the place where we need to post the login information.  Post the form
   -- to login.
   --
-  local domainWithUnderscore = string.gsub(domain, "%.", "_")
-  local pattern = string.format(globals.strLoginPostUrlPattern3, domainWithUnderscore)
+  local pattern = string.format(globals.strLoginPostUrlPattern3, domain)
   _, _, url = string.find(body, pattern)
+  local _, _, str = string.find(body, globals.strLoginPostUrlPattern4)
+  local _, _, str2 = string.find(body, globals.strLoginPostUrlPattern5)
+  if (url == nil or str == nil or str2 == nil) then
+    log.error_print(globals.strLoginFailed)
+    return POPSERVER_ERR_AUTH
+  end
+  url = url .. "?" .. str 
+
   local padding = string.sub(globals.strLoginPaddingFull, 0, 16 - passwordlen)
   postdata = string.format(globals.strLoginPostData, username, domain, password, padding)
+  postdata = postdata .. "&PPFT=" .. str2
 
+  log.dbg("Hotmail - Sending login information to: " .. url)
   body, err = browser:post_uri(url, postdata)
 
   -- We should be logged in now!  Unfortunately, we aren't done.  Hotmail returns a page
@@ -268,8 +283,8 @@ function loginHotmail()
     log.error_print(globals.strLoginFailed)
     return POPSERVER_ERR_AUTH
   end
-  
-  local _, _, str = string.find(url, globals.strRetLoginBadLogin)
+
+  _, _, str = string.find(url, globals.strRetLoginBadLogin)
   if str ~= nil then
     log.error_print(globals.strLoginFailed)
     return POPSERVER_ERR_AUTH
