@@ -17,7 +17,7 @@
 -- ************************************************************************** --
 --  FreePOPs @libero.it, @inwind.it, @blu.it, @iol.it webmail interface
 --  
---  $Id: libero.lua,v 1.37 2005/01/31 22:50:10 alessiofender Exp $
+--  $Id: libero.lua,v 1.39 2005/06/27 17:58:09 gareuselesinge Exp $
 --  
 --  Released under the GNU/GPL license
 --  Written by Enrico Tassi <gareuselesinge@users.sourceforge.net>
@@ -31,8 +31,8 @@ PLUGIN_VERSION = "0.2.1"
 PLUGIN_NAME = "Libero.IT"
 PLUGIN_REQUIRE_VERSION = "0.0.14"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=libero.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net/"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=libero.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org/"
 
 -- list of strings, one required, one contact for each author
 PLUGIN_AUTHORS_NAMES = {"Enrico Tassi"}
@@ -106,8 +106,9 @@ local libero_string = {
 	first = "http://%s/cgi-bin/webmail.cgi?ID=%s&Act_Msgs=1&"..
 		"C_Folder=%s",
 	-- The capture to check if there is one more page of message list
-	next_checkC = "<a href=\"javascript:doit"..
-		"%('Act_Msgs_Page_Next',1,1%)\">.*</a>",
+
+	next_checkC = "<a%s+href=\"javascript:doit"..
+		"%('Act_Msgs_Page_Next',1,1%)\".*</a>",
 	-- The uri to get the next page of messages
 	next = "http://%s/cgi-bin/webmail.cgi?ID=%s&Act_Msgs_Page_Next=1&"..
 		"HELP_ID=inbox&SEL_ALL=0&"..
