@@ -2,7 +2,7 @@
 --  FreePOPs @foo.xx webmail interface, the plugin made in the tutorial,
 --  see the manal for more infos about this simple example
 -- 
---  $Id: supereva.lua,v 1.8 2005/02/04 20:57:12 alessiofender Exp $
+--  $Id: supereva.lua,v 1.10 2005/06/03 16:29:22 alessiofender Exp $
 -- 
 --  Released under the GNU/GPL license
 --  Written by Me <Me@myhouse>
@@ -13,8 +13,8 @@ PLUGIN_VERSION = "0.0.8"
 PLUGIN_NAME = "Supereva web mail"
 PLUGIN_REQUIRE_VERSION = "0.0.22"
 PLUGIN_LICENSE = "GNU/GPL"
-PLUGIN_URL = "http://freepops.sourceforge.net/download.php?file=supereva.lua"
-PLUGIN_HOMEPAGE = "http://freepops.sourceforge.net"
+PLUGIN_URL = "http://www.freepops.org/download.php?file=supereva.lua"
+PLUGIN_HOMEPAGE = "http://www.freepops.org"
 PLUGIN_AUTHORS_NAMES = {"Andrea Dalle Molle","Enrico Tassi"}
 PLUGIN_AUTHORS_CONTACTS = {"Tund3r (at) fastwebnet (dot) it",
 	"gareuselesinge (at) users (dot) sourceforge (dot) net"}
@@ -604,8 +604,8 @@ function mangle_head(s)
   
 	-- helper #1 - extract a header field from HTML
 	local function extract(field,data)
-		local exM = ".*<td><b>%s</b></td><td>.*<.*>"
-		local exG = "O<O><O>O<O><O><O>X<O>"
+		local exM = ".*<td>.*<b>%s</b>.*</td>.*<td>.*<.*>"
+		local exG = "O<O>O<O>O<O>O<O>O<O>X<O>"
 		local x = mlex.match(data,string.format(exM,field),exG)
 		--x:print()
 		if x:count() < 1 then
